#include "stdafx.h"
#include "ViewsManager.h"
#include "IEndoDisplay.h"

#define D_DPY3D_DLL                 _T("Display3d.dll")
#define D_DPY3D_DBG_DLL             _T("Display3dD.dll")
#define D_DPY3D_ENTRY               "Build3dView"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

static ViewsManager* pInstance = NULL;

//!----------------------------------------------------------------------------
ViewsManager::ViewsManager()
{    
  ASSERT (!pInstance);
  pInstance = this;
  m_hDpy3d = 0;  
  m_pDpy3d = NULL;
}
//!----------------------------------------------------------------------------
ViewsManager::~ViewsManager()
{
}
//!--------------------------------------------------------------------------  
void 
ViewsManager::LoadDisplayResources ()
{   
  try
  {
    LoadDpy3d ();
  }
  catch(ViewMgrExcp err)
  {
    err.LogReport();
  }
}

//!--------------------------------------------------------------------------  
void 
ViewsManager::LoadDpy3d ()
{
  typedef IEndoDisplay* (*tFuncPtr) (DWORD iVersion);

  ::SetLastError(0L);
  ::SetErrorMode(0);

#ifdef _DEBUG
  m_hDpy3d = AfxLoadLibrary (D_DPY3D_DBG_DLL);    
#else 
  m_hDpy3d = AfxLoadLibrary (D_DPY3D_DLL);    
#endif
  
  if (m_hDpy3d == NULL) {		
    CString msg (_T("Unable to load Display3d check configuration"));
	DWORD dw = ::GetLastError();
    std::wstringstream wss;
	wss << "Failed: Error code " << dw;
	CString txt = wss.str().c_str();
    throw ViewMgrExcp (txt);
  }

  FARPROC pnProc = GetProcAddress (m_hDpy3d, D_DPY3D_ENTRY); 
  tFuncPtr pfuncPtr = (tFuncPtr)pnProc;    

  m_pDpy3d = pfuncPtr (0);   

  CString logtxt(_T("Loaded Display3d dll")); 
  TRACE(logtxt);
}
//!--------------------------------------------------------------------------  
void 
ViewsManager::UnloadDisplayResources ()
{  
  if (m_hDpy3d) {
    if (m_pDpy3d) delete m_pDpy3d;
    FreeLibrary (m_hDpy3d);
  }
}
//!--------------------------------------------------------------------------  
void 
ViewsManager::CreateDisplayWnd (HWND child)
{
  DWORD dwStyle = AFX_WS_DEFAULT_VIEW | CS_OWNDC | WS_CHILD; 
  dwStyle &= ~WS_BORDER;  				      
  
  if (m_pDpy3d) {
    m_pDpy3d->create (dwStyle, child, AFX_IDW_PANE_FIRST);  
  }
}

//!--------------------------------------------------------------------------  
HWND 
ViewsManager::getDpy3dHandle ()
{
  if (!m_pDpy3d)
    return NULL;

  return m_pDpy3d->getDisplay ();  
}